#ifndef dplyr_dplyr_main_H
#define dplyr_dplyr_main_H

#include <Rcpp.h>
#include <dplyr/workarounds/installChar.h>
#include <dplyr/workarounds/static_assert.h>
#include <dplyr/workarounds/xlen.h>
#include <solaris/solaris.h>
#include <dplyr/config.h>

#include <plogr.h>

using namespace Rcpp;

#endif // #ifndef dplyr_dplyr_main_H
